#ifdef __CINT__
#pragma link off all globals;
#pragma link off all classes;
#pragma link off all functions;
#pragma link C++ class Roo2DKeysPdf+ ;
#pragma link C++ class RooArgusBG+ ;
#pragma link C++ class RooBCPEffDecay+ ;
#pragma link C++ class RooBCPGenDecay+ ;
#pragma link C++ class RooBDecay+ ;
#pragma link C++ class RooBlindTools+ ;
#pragma link C++ class RooBifurGauss+ ;
#pragma link C++ class RooBMixDecay+ ;
#pragma link C++ class RooBreitWigner+ ;
#pragma link C++ class RooBukinPdf+ ;
#pragma link C++ class RooCrystalBall+ ;
#pragma link C++ class RooCBShape+ ;
#pragma link C++ class RooChebychev+ ;
#pragma link C++ class RooDecay+ ;
#pragma link C++ class RooDstD0BG+ ;
#pragma link C++ class RooExponential+ ;
#pragma link C++ class RooGaussian+ ;
#pragma link C++ class RooLognormal+ ;
#pragma link C++ class RooGamma+ ;
#pragma link C++ class RooGaussModel+ ;
#pragma link C++ class RooGExpModel+ ;
#pragma link C++ class RooHistConstraint+ ;
#pragma link C++ class RooKeysPdf+ ;
#pragma link C++ class RooNDKeysPdf+ ;
#pragma link C++ class RooNDKeysPdf::BoxInfo+;
#pragma link C++ class RooLandau+ ;
#pragma link C++ class RooNonCPEigenDecay+ ;
#pragma link C++ class RooNovosibirsk+ ;
#pragma link C++ class RooParamHistFunc+ ;
#pragma link C++ class RooParametricStepFunction+ ;
#pragma link C++ class RooPolynomial+ ;
#pragma link C++ class RooUnblindCPAsymVar+ ;
#pragma link C++ class RooUnblindOffset+ ;
#pragma link C++ class RooUnblindPrecision+ ;
#pragma link C++ class RooUnblindUniform+ ;
#pragma link C++ class RooVoigtian+ ;
#pragma link C++ class RooPoisson+ ;
#pragma link C++ class RooChi2MCSModule+ ;
#pragma link C++ class RooTFnBinding+ ;
#pragma link C++ class RooTFnPdfBinding+ ;
#pragma link C++ class RooBernstein+ ;
#pragma link C++ class RooChiSquarePdf+ ;
#pragma link C++ class RooIntegralMorph+ ;
#pragma link C++ class RooIntegralMorph::MorphCacheElem+ ;
#pragma link C++ class RooMomentMorph+ ;
#pragma link C++ class RooMomentMorphFunc + ;
#pragma link C++ class RooMomentMorphFuncND + ;
#pragma link C++ class RooMomentMorphFuncND::Grid2 + ;
#pragma link C++ class RooSpline+ ;
#pragma link C++ class RooStepFunction+ ;
#pragma link C++ class RooMultiBinomial+ ;
/* #pragma link C++ class std::vector< TVector2 >; */
/* #pragma link C++ class std::vector< TVector2 >::iterator ; */
/* #pragma link C++ class RooPolyMorph2D+ ; */
//
#pragma link C++ class RooUniform+ ;
#pragma link C++ class RooJeffreysPrior+ ;
#pragma link C++ class RooJohnson+;
#pragma link C++ class RooLagrangianMorphFunc+;
#pragma link C++ class RooLagrangianMorphFunc::Config+;
#pragma read sourceClass="RooLagrangianMorphFunc" targetClass="RooLagrangianMorphFunc" version="[1]" \
  source="std::vector<RooListProxy *> _nonInterfering;" target="_nonInterfering" \
  code="{ for(RooListProxy const * list : onfile._nonInterfering) {  \
             _nonInterfering.emplace_back();                         \
             for(RooAbsArg * arg : *list) {                          \
                _nonInterfering.back().emplace_back(arg->GetName()); \
             }                                                       \
          } }";
#pragma link C++ class RooFunctorBinding+ ;
#pragma link C++ class RooFunctor1DBinding+ ;
#pragma link C++ class RooFunctorPdfBinding+ ;
#pragma link C++ class RooFunctor1DPdfBinding+ ;
//
#pragma link C++ class RooCFunction1Ref<double,double>- ;
#pragma link C++ class RooCFunction1Binding<double,double>+ ;
#pragma link C++ class RooCFunction1PdfBinding<double,double>+ ;
#pragma link C++ class RooCFunction1Ref<double,Int_t>- ;
#pragma link C++ class RooCFunction1Binding<double,Int_t>+ ;
#pragma link C++ class RooCFunction1PdfBinding<double,Int_t>+ ;
//
#pragma link C++ class RooCFunction2Ref<double,double,double>- ;
#pragma link C++ class RooCFunction2Binding<double,double,double>+ ;
#pragma link C++ class RooCFunction2PdfBinding<double,double,double>+ ;
#pragma link C++ class RooCFunction2Ref<double,Int_t,double>- ;
#pragma link C++ class RooCFunction2Binding<double,Int_t,double>+ ;
#pragma link C++ class RooCFunction2PdfBinding<double,Int_t,double>+ ;
#pragma link C++ class RooCFunction2Ref<double,UInt_t,double>- ;
#pragma link C++ class RooCFunction2Binding<double,UInt_t,double>+ ;
#pragma link C++ class RooCFunction2PdfBinding<double,UInt_t,double>+ ;
#pragma link C++ class RooCFunction2Ref<double,double,Int_t>- ;
#pragma link C++ class RooCFunction2Binding<double,double,Int_t>+ ;
#pragma link C++ class RooCFunction2PdfBinding<double,double,Int_t>+ ;
#pragma link C++ class RooCFunction2Ref<double,Int_t,Int_t>- ;
#pragma link C++ class RooCFunction2Binding<double,Int_t,Int_t>+ ;
#pragma link C++ class RooCFunction2PdfBinding<double,Int_t,Int_t>+ ;
//
#pragma link C++ class RooCFunction3Ref<double,double,double,double>- ;
#pragma link C++ class RooCFunction3Binding<double,double,double,double>+ ;
#pragma link C++ class RooCFunction3PdfBinding<double,double,double,double>+ ;
#pragma link C++ class RooCFunction3Ref<double,double,double,bool>- ;
#pragma link C++ class RooCFunction3Binding<double,double,double,bool>+ ;
#pragma link C++ class RooCFunction3PdfBinding<double,double,double,bool>+ ;
#pragma link C++ class RooCFunction3Ref<double,double,Int_t,Int_t>- ;
#pragma link C++ class RooCFunction3Binding<double,double,Int_t,Int_t>+ ;
#pragma link C++ class RooCFunction3PdfBinding<double,double,Int_t,Int_t>+ ;
#pragma link C++ class RooCFunction3Ref<double,UInt_t,double,UInt_t>- ;
#pragma link C++ class RooCFunction3Binding<double,UInt_t,double,UInt_t>+ ;
#pragma link C++ class RooCFunction3PdfBinding<double,UInt_t,double,UInt_t>+ ;
#pragma link C++ class RooCFunction3Ref<double,UInt_t,double,double>- ;
#pragma link C++ class RooCFunction3Binding<double,UInt_t,double,double>+ ;
#pragma link C++ class RooCFunction3PdfBinding<double,UInt_t,double,double>+ ;
#pragma link C++ class RooCFunction3Ref<double,UInt_t,UInt_t,double>- ;
#pragma link C++ class RooCFunction3Binding<double,UInt_t,UInt_t,double>+ ;
#pragma link C++ class RooCFunction3PdfBinding<double,UInt_t,UInt_t,double>+ ;
//
#pragma link C++ class RooCFunction4Ref<double,double,double,double,double>- ;
#pragma link C++ class RooCFunction4Binding<double,double,double,double,double>+ ;
#pragma link C++ class RooCFunction4PdfBinding<double,double,double,double,double>+ ;
#pragma link C++ class RooCFunction4Ref<double,double,double,double,Int_t>- ;
#pragma link C++ class RooCFunction4Binding<double,double,double,double,Int_t>+ ;
#pragma link C++ class RooCFunction4PdfBinding<double,double,double,double,Int_t>+ ;
#pragma link C++ class RooCFunction4Ref<double,double,double,double,bool>- ;
#pragma link C++ class RooCFunction4Binding<double,double,double,double,bool>+ ;
#pragma link C++ class RooCFunction4PdfBinding<double,double,double,double,bool>+ ;

//#ifdef USE_FOR_AUTLOADING
//#pragma link C++ class RooFit ;
//#else
#pragma link C++ namespace RooFit ;
//#endif
//
#endif
